---
title: Overview
page_title: Overview | Kendo UI PivotGrid for Vue
description: "Get an overview of the features the Kendo UI PivotGrid delivers and use the component in Vue projects."
slug: overview_pivotgrid
position: 0
---

# PivotGrid Overview

The PivotGrid component is a client-side wrapper for the Kendo UI [PivotGrid widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/pivotgrid).

It allows the user to perform a complex analysis on the visualized data. The widget uses the Online Analytical Processing ([OLAP](https://en.wikipedia.org/wiki/Online_analytical_processing)) approach to present the result of multidimensional queries in a comprehensive way. It also supports a drill-down functionality that represents the underlying data for calculated cells. The PivotGrid uses an instance of the [kendo.data.PivotDataSource](https://docs.telerik.com/kendo-ui/api/javascript/data/pivotdatasource) component as a data source. PivotDataSource communicates with an [OLAP cube](https://en.wikipedia.org/wiki/OLAP_cube) instance on HTTP using the [XMLA protocol](https://en.wikipedia.org/wiki/XML_for_Analysis).

## Getting Started

To initialize the PivotGrid, either:
* [Use the CDN service](#toc-initializing-from-cdn), or
* [Use Webpack](#toc-initializing-with-webpack).

### Initializing from CDN

The following example demonstrates how to initialize the PivotGrid with the wrapper for Vue. To access all CDN references, open the sample as Plunker.

{% meta height:660 %}
```html-preview
<div id="vueapp" class="vue-app">
    <kendo-pivotdatasource ref="pivotdatasource"
                           :transport-read-url="'https://demos.telerik.com/kendo-ui/service/Northwind.svc/Customers'"
                           :type="'odata'"
                           :schema-cube="schemaCube"
                           :measures="measures">
        <kendo-pivot-column :name="'Country'" :expand="true"></kendo-pivot-column>
        <kendo-pivot-column :name="'CompanyName'"></kendo-pivot-column>
        <kendo-pivot-row :name="'ContactTitle'"></kendo-pivot-row>
    </kendo-pivotdatasource>

    <kendo-pivotconfigurator id="configurator"
                             class="hidden-on-narrow"
                             :data-source-ref="'pivotdatasource'"
                             :filterable="true"
                             :height="570">
    </kendo-pivotconfigurator>

   <kendo-pivotgrid id="pivotgrid"
                    class="hidden-on-narrow"
                    :data-source-ref="'pivotdatasource'"
                    :filterable="true"
                    :columnWidth="120"
                    :height="570">
    </kendo-pivotgrid>
</div>
<style>
    .hidden-on-narrow {
        display: inline-block;
        vertical-align: top;
    }

    #pivotgrid {
        width: 58%;
    }

    #configurator {
        width: 41%;
        min-width: 41%;
    }
</style>
```
```js
Vue.use(PivotGridInstaller);
Vue.use(DataSourceInstaller);

new Vue({
    el: '#vueapp',
    data: function() {
        return {
            measures: ['Contacts Count'],
            schemaCube: {
                dimensions: {
                    ContactName: { caption: 'All Contacts' },
                    CompanyName: { caption: 'All Companies' },
                    Country: { caption: 'All Countries' },
                    ContactTitle: { caption: 'All Titles' }
                },
                measures: {
                    'Contacts Count': { field: 'CustomerID', aggregate: 'count' }
                }
            }
        }
    }
})
```
{% endmeta %}

### Initializing with Webpack

1. Install Kendo UI and add a theme:

    ```sh
    npm install --save @progress/kendo-ui
    npm install --save @progress/kendo-theme-default
    ```

1. Install the Kendo UI for Vue PivotGrid package:

    ```sh
    npm install --save @progress/kendo-pivotgrid-vue-wrapper
    ```

1. Import the Kendo UI packages to the App component. Add all Kendo UI-related files either to the main.js file if you will use them in several places in your application or to another component where they will be used.

    ```js-no-run
    import '@progress/kendo-ui'
    import '@progress/kendo-theme-default/dist/all.css'

    import { PivotGrid, PivotGridInstaller } from '@progress/kendo-pivotgrid-vue-wrapper'

    Vue.use(PivotGridInstaller)

    new Vue({
        el: '#app',
        components: {
            PivotGrid
        }
    })
    ```


## Suggested Links

* [API Reference of the PivotGrid](http://docs.telerik.com/kendo-ui/api/javascript/ui/pivotgrid)
